package com.muyu.authentication;

import com.alibaba.fastjson.JSON;
import com.muyu.authentication.mapper.MessageAnalysisMapper;
import com.muyu.authentication.mapper.VehicleMapper;
import com.muyu.clw.common.many.datasource.holder.DynamicDataSourceHolder;
import com.muyu.clw.common.many.remote.RemoteEnterpriseService;
import com.muyu.common.core.domain.Result;
import com.muyu.common.security.annotation.EnableCustomConfig;
import com.muyu.common.security.annotation.EnableMyFeignClients;
import com.muyu.common.swagger.annotation.EnableCustomSwagger2;
import com.muyu.domain.Enterprise;
import com.muyu.many.domain.MessageAnalysis;
import com.muyu.many.domain.Vehicle;
import org.apache.commons.collections4.map.HashedMap;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.ApplicationArguments;
import org.springframework.boot.ApplicationRunner;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.scheduling.annotation.EnableScheduling;

import java.util.*;
import java.util.concurrent.TimeUnit;

/**
 * 企业模块
 *
 * @author muyu
 */
@EnableScheduling
@EnableCustomConfig
@EnableCustomSwagger2
@EnableMyFeignClients
@SpringBootApplication
public class  MuYuManyApplication implements ApplicationRunner {
    public static void main (String[] args) {
        SpringApplication.run(MuYuManyApplication.class, args);
    }

    @Autowired
    private RemoteEnterpriseService remoteEnterpriseService;
    @Autowired
    private VehicleMapper vehicleMapper;
    @Autowired
    private RedisTemplate<String,String> redisTemplate;
    @Autowired
    private MessageAnalysisMapper messageAnalysisMapper;

    @Override
    public void run(ApplicationArguments args) throws Exception {
        Result<List<Enterprise>> enterprised = remoteEnterpriseService.enterpriseAllList();
        List<Enterprise> enterpriseList = enterprised.getData();


        for (Enterprise enterprise1 : enterpriseList) {
            String ent = "ent_" + enterprise1.getContactPhone().substring(enterprise1.getContactPhone().length() - 4);
            DynamicDataSourceHolder.setDynamicDataSourceKey(ent);
            List<Vehicle> vehicles = vehicleMapper.selectList(null);
            List<MessageAnalysis> messageAnalyses = messageAnalysisMapper.selectList(null);

            for (Vehicle vehicle : vehicles) {
                redisTemplate.opsForValue().set(vehicle.getVin(), JSON.toJSONString(messageAnalyses),4,TimeUnit.HOURS);
            }
        }
    }
}
